@@ -1,7 +1,7 @@
 from django.shortcuts import render, redirect
 from django.views.generic import View
 from .forms import LinkForm
-from . import main
+from .crawler import main
 
 
 class Index(View):
